/**
 * @file
 * Javascript behaviors for YAML form signature_pad integration.
 */

(function ($, Drupal) {

  'use strict';

  Drupal.behaviors.yamlFormElementSignature = {
    attach: function (context) {
      $(context).find('input.js-yamlform-signature').once('yamlform-signature').each(function () {
        var $input = $(this);
        var value = $input.val();
        var $wrapper = $input.parent();
        var $canvas = $wrapper.find('canvas');
        var $button = $wrapper.find('input[type="submit"]');
        var canvas = $canvas[0];

        // Set height.
        $canvas.attr('width', $wrapper.width());
        $canvas.attr('height', $wrapper.width()/3);
        $(window).resize(function () {
          $canvas.attr('width', $wrapper.width());
          $canvas.attr('height', $wrapper.width()/3);

          // Resizing clears the canvas so we need to reset the signature pad.
          signaturePad.clear();
          var value = $input.val();
          if (value) {
            signaturePad.fromDataURL(value);
          }
        });

        // Initialize signature canvas.
        var signaturePad = new SignaturePad(canvas, {
          'onEnd': function () {
            $input.val(signaturePad.toDataURL());
          }
        });

        // Set value.
        if (value) {
          signaturePad.fromDataURL(value);
        }

        // Set reset handler.
        $button.on('click', function () {
          signaturePad.clear();
          $input.val();
          this.blur();
          return false;
        });
      });
    }
  };

})(jQuery, Drupal);
